@@ -3,8 +3,6 @@
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    License    : BSD3
 
-   Maintainer : John Goerzen <jgoerzen@complete.org>
-   Stability  : provisional
    Portability: portable
 
 Simple log handlers
@@ -17,7 +15,8 @@ module System.Log.Handler.Simple(streamHandler, fileHandler,
                                       verboseStreamHandler)
     where
 
-import Control.Exception (SomeException, tryJust)
+import Control.Exception (tryJust)
+import Control.DeepSeq
 import Data.Char (ord)
 
 import System.Log
@@ -53,6 +52,7 @@ streamHandler :: Handle -> Priority -> IO (GenericHandler Handle)
 streamHandler h pri =
     do lock <- newMVar ()
        let mywritefunc hdl msg =
+               msg `deepseq`
                withMVar lock (\_ -> do writeToHandle hdl msg
                                        hFlush hdl
                              )
@@ -60,7 +60,7 @@ streamHandler h pri =
                                formatter = nullFormatter,
                                privData = h,
                                writeFunc = mywritefunc,
-                               closeFunc = \x -> return ()})
+                               closeFunc = \_ -> return ()})
     where
       writeToHandle hdl msg = do
           rv <- tryJust myException (hPutStrLn hdl msg)
